# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PythonPackageVersionsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"versions": "list[PythonPackageVersionsResponseVersions]"}

    attribute_map = {"versions": "versions"}

    def __init__(self, versions=None):  # noqa: E501
        """PythonPackageVersionsResponse - a model defined in Swagger"""  # noqa: E501
        self._versions = None
        self.discriminator = None
        self.versions = versions

    @property
    def versions(self):
        """Gets the versions of this PythonPackageVersionsResponse.  # noqa: E501


        :return: The versions of this PythonPackageVersionsResponse.  # noqa: E501
        :rtype: list[PythonPackageVersionsResponseVersions]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this PythonPackageVersionsResponse.


        :param versions: The versions of this PythonPackageVersionsResponse.  # noqa: E501
        :type: list[PythonPackageVersionsResponseVersions]
        """
        if versions is None:
            raise ValueError(
                "Invalid value for `versions`, must not be `None`"
            )  # noqa: E501

        self._versions = versions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PythonPackageVersionsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PythonPackageVersionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
